package com.jiuqi.dna.ide.designer.commands;

import com.jiuqi.dna.ide.designer.DesignerMessages;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import org.eclipse.gef.commands.Command;

/* loaded from: com_jiuqi_dna_ide_designer_commands.jar:com/jiuqi/dna/ide/designer/commands/LinkChangeCommand.class */
public class LinkChangeCommand extends Command {
    private ILinkElement link;
    private IFigureElement node;
    private IFigureElement oldNode;
    private boolean sourceChanged;

    public LinkChangeCommand(ILinkElement link, IFigureElement node, boolean sourceChanged) {
        if (link == null) {
            throw new NullPointerException("参数link不能为NULL！");
        }
        if (node == null) {
            throw new NullPointerException("参数node不能为NULL！");
        }
        this.link = link;
        this.node = node;
        this.sourceChanged = sourceChanged;
        if (sourceChanged) {
            this.oldNode = link.getSource();
        } else {
            this.oldNode = link.getTarget();
        }
        setLabel(DesignerMessages.LinkChangeCommandLabel);
    }

    public boolean canExecute() {
        return this.link.isChangeable(this.node, this.sourceChanged);
    }

    public void execute() {
        if (this.sourceChanged) {
            this.oldNode.removeSourceLink(this.link);
            this.node.addSourceLink(this.link);
            this.link.setSource(this.node);
        } else {
            this.oldNode.removeTargetLink(this.link);
            this.node.addTargetLink(this.link);
            this.link.setTarget(this.node);
        }
    }

    public void undo() {
        if (this.sourceChanged) {
            this.node.removeSourceLink(this.link);
            this.oldNode.addSourceLink(this.link);
            this.link.setSource(this.oldNode);
        } else {
            this.node.removeTargetLink(this.link);
            this.oldNode.addTargetLink(this.link);
            this.link.setTarget(this.oldNode);
        }
    }
}
